@@ -440,7 +440,7 @@ class Client(object):
             self.http = requests.Session()
         try:
             return self.http.request(method, url, headers=headers, data=body)
-        except requests.exceptions.ConnectionError:
+        except requests.exceptions.RequestException:
             pass
 
     def _trigger_event(self, event, *args, **kwargs):
@@ -488,7 +488,7 @@ class Client(object):
         self.ping_loop_event.clear()
         while self.state == 'connected':
             if not self.pong_received:
-                self.logger.warning(
+                self.logger.info(
                     'PONG response has not been received, aborting')
                 if self.ws:
                     self.ws.close()
