@@ -433,7 +433,7 @@ class TestClient(unittest.TestCase):
                           transports=['websocket'], headers={'Foo': 'Bar'})
         create_connection.assert_called_once_with(
             'ws://foo/engine.io/?transport=websocket&EIO=3&t=123.456',
-            header={'Foo': 'Bar'})
+            header={'Foo': 'Bar'}, cookie=None)
 
     @mock.patch('engineio.client.time.time', return_value=123.456)
     @mock.patch('engineio.client.websocket.create_connection',
@@ -444,7 +444,7 @@ class TestClient(unittest.TestCase):
         self.assertFalse(c.connect('http://foo', transports=['websocket']))
         create_connection.assert_called_once_with(
             'ws://foo/engine.io/?transport=websocket&EIO=3&sid=123&t=123.456',
-            header={})
+            header={}, cookie=None)
 
     @mock.patch('engineio.client.websocket.create_connection')
     def test_websocket_connection_no_open_packet(self, create_connection):
@@ -486,6 +486,36 @@ class TestClient(unittest.TestCase):
         self.assertEqual(c.upgrades, [])
         self.assertEqual(c.transport(), 'websocket')
         self.assertEqual(c.ws, create_connection.return_value)
+        self.assertEqual(len(create_connection.call_args_list), 1)
+        self.assertEqual(create_connection.call_args[1],
+                         {'header': {}, 'cookie': None})
+
+    @mock.patch('engineio.client.websocket.create_connection')
+    def test_websocket_connection_with_cookies(self, create_connection):
+        create_connection.return_value.recv.return_value = packet.Packet(
+            packet.OPEN, {
+                'sid': '123', 'upgrades': [], 'pingInterval': 1000,
+                'pingTimeout': 2000
+            }).encode()
+        c = client.Client()
+        c.http = mock.MagicMock()
+        c.http.cookies = [mock.MagicMock(), mock.MagicMock()]
+        c.http.cookies[0].name = 'key'
+        c.http.cookies[0].value = 'value'
+        c.http.cookies[1].name = 'key2'
+        c.http.cookies[1].value = 'value2'
+        c._ping_loop = mock.MagicMock()
+        c._read_loop_polling = mock.MagicMock()
+        c._read_loop_websocket = mock.MagicMock()
+        c._write_loop = mock.MagicMock()
+        on_connect = mock.MagicMock()
+        c.on('connect', on_connect)
+        c.connect('ws://foo', transports=['websocket'])
+        time.sleep(0.1)
+
+        self.assertEqual(len(create_connection.call_args_list), 1)
+        self.assertEqual(create_connection.call_args[1],
+                         {'header': {}, 'cookie': 'key=value; key2=value2'})
 
     @mock.patch('engineio.client.websocket.create_connection')
     def test_websocket_upgrade_no_pong(self, create_connection):
@@ -515,7 +545,7 @@ class TestClient(unittest.TestCase):
     @mock.patch('engineio.client.websocket.create_connection')
     def test_websocket_upgrade_successful(self, create_connection):
         create_connection.return_value.recv.return_value = packet.Packet(
-            packet.PONG, 'probe').encode()
+            packet.PONG, six.text_type('probe')).encode()
         c = client.Client()
         c.sid = '123'
         c.base_url = 'http://foo'
@@ -541,7 +571,8 @@ class TestClient(unittest.TestCase):
         self.assertEqual(c.ws, create_connection.return_value)
         self.assertEqual(
             create_connection.return_value.send.call_args_list[0],
-            ((packet.Packet(packet.PING, 'probe').encode(),),))  # ping
+            ((packet.Packet(packet.PING, six.text_type('probe')).encode(),),)
+        )  # ping
         self.assertEqual(
             create_connection.return_value.send.call_args_list[1],
             ((packet.Packet(packet.UPGRADE).encode(),),))  # upgrade
